#
# Copyright IBM Corp. 2024 - 2024
# SPDX-License-Identifier: MIT
#

"""ONNX-based document figure classifier."""

from .document_figure_classifier_predictor import DocumentFigureClassifierPredictor

__all__ = ["DocumentFigureClassifierPredictor"]
